[Datatype-cvs] rm/video/renderer rvxvdfmt.cpp,1.25.2.8,1.25.2.9

[Datatype-cvs] rm/video/renderer rvxvdfmt.cpp,1.25.2.8,1.25.2.9

ehyche at helixcommunity.org ehyche at helixcommunity.org
Tue Oct 25 12:00:29 PDT 2005


Update of /cvsroot/datatype/rm/video/renderer
In directory cvs:/tmp/cvs-serv10779

Modified Files:
      Tag: hxclient_1_5_0_cayenne
	rvxvdfmt.cpp 
Log Message:
Merge from HEAD.
Report missing frames coming out of the
depacketizer as lost, not dropped.
CR ping at real.com and milko at real.com


Index: rvxvdfmt.cpp
===================================================================
RCS file: /cvsroot/datatype/rm/video/renderer/rvxvdfmt.cpp,v
retrieving revision 1.25.2.8
retrieving revision 1.25.2.9
diff -u -d -r1.25.2.8 -r1.25.2.9
--- rvxvdfmt.cpp	18 Oct 2005 21:56:09 -0000	1.25.2.8
+++ rvxvdfmt.cpp	25 Oct 2005 19:00:27 -0000	1.25.2.9
@@ -663,7 +663,7 @@
 	    pFramePacket->SetBufferKiller(KillInputBuffer);
 	    pFramePacket->m_pUserData = this;
 
 	    // Report missing frames as dropped
 	    if (m_ulLastSequenceNumber != UNINITIALIZED_SEQ_NUMBER &&
                 (m_lPlaybackVelocity   == HX_PLAYBACK_VELOCITY_NORMAL ||
                  !m_bKeyFrameMode))
@@ -675,7 +675,7 @@
 		    if (m_pRVXVideoRenderer->IsActive() ||
 			(((LONG32) (pCodecPacket->timestamp - GetStartTime())) > 0))
 		    {
-			m_pRVXVideoRenderer->ReportDroppedFrame(uFramesDropped);
+			m_pRVXVideoRenderer->ReportLostFrame(uFramesDropped);
 		    }
 		}
 	    }
@@ -663,7 +663,7 @@
 	    pFramePacket->m_pUserData = this;
 
-	    // Report missing frames as dropped
+	    // Report missing frames as lost
 	    if (m_ulLastSequenceNumber != UNINITIALIZED_SEQ_NUMBER &&
                 (m_lPlaybackVelocity   == HX_PLAYBACK_VELOCITY_NORMAL ||




More information about the Datatype-cvs mailing list
 

Site Map   |   Terms of Use   |   Privacy Policy   |   Contact Us

Copyright © 1995-2007 RealNetworks, Inc. All rights reserved. RealNetworks and Helix are trademarks of RealNetworks.
All other trademarks or registered trademarks are the property of their respective holders.